@@ -1,9 +1,9 @@
 package ArrayDataRole::Source::Iterator;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-04-25'; # DATE
+our $DATE = '2021-05-03'; # DATE
 our $DIST = 'ArrayDataRoles-Standard'; # DIST
-our $VERSION = '0.004'; # VERSION
+our $VERSION = '0.005'; # VERSION
 
 use 5.010001;
 use Role::Tiny;
@@ -65,6 +65,26 @@ sub get_iterator_pos {
     $self->{pos};
 }
 
+sub get_item_at_pos {
+    my ($self, $pos) = @_;
+    $self->reset_iterator if $self->{pos} > $pos;
+    while (1) {
+        die "Out of range" unless $self->has_next_item;
+        my $item = $self->get_next_item;
+        return $item if $self->{pos} > $pos;
+    }
+}
+
+sub has_item_at_pos {
+    my ($self, $pos) = @_;
+    return 1 if $self->{pos} > $pos;
+    while (1) {
+        return 0 unless $self->has_next_item;
+        $self->get_next_item;
+        return 1 if $self->{pos} > $pos;
+    }
+}
+
 1;
 # ABSTRACT: Get array data from an iterator
 
@@ -80,7 +100,7 @@ ArrayDataRole::Source::Iterator - Get array data from an iterator
 
 =head1 VERSION
 
-This document describes version 0.004 of ArrayDataRole::Source::Iterator (from Perl distribution ArrayDataRoles-Standard), released on 2021-04-25.
+This document describes version 0.005 of ArrayDataRole::Source::Iterator (from Perl distribution ArrayDataRoles-Standard), released on 2021-05-03.
 
 =head1 SYNOPSIS
 
@@ -107,6 +127,10 @@ elements have been iterated.
 
 C<reset_iterator()> will regenerate a new iterator.
 
+Note: C<get_item_at_pos()> and C<has_item_at_pos()> are slow (O(n) in worst
+case) because they iterate. Caching might be added in the future to speed this
+up.
+
 =for Pod::Coverage ^(.+)$
 
 =head1 ROLES MIXED IN
@@ -141,7 +165,7 @@ Source repository is at L<https://github.com/perlancar/perl-ArrayDataRoles-Stand
 
 =head1 BUGS
 
-Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=ArrayDataRoles-Standard>
+Please report any bugs or feature requests on the bugtracker website L<https://github.com/perlancar/perl-ArrayDataRoles-Standard/issues>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
