@@ -1,9 +1,9 @@
 package ArrayDataRole::Source::LinesInDATA;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-04-25'; # DATE
+our $DATE = '2021-05-03'; # DATE
 our $DIST = 'ArrayDataRoles-Standard'; # DIST
-our $VERSION = '0.004'; # VERSION
+our $VERSION = '0.005'; # VERSION
 
 use Role::Tiny;
 use Role::Tiny::With;
@@ -48,6 +48,26 @@ sub reset_iterator {
     $self->{pos} = 0;
 }
 
+sub get_item_at_pos {
+    my ($self, $pos) = @_;
+    $self->reset_iterator if $self->{pos} > $pos;
+    while (1) {
+        die "Out of range" unless $self->has_next_item;
+        my $item = $self->get_next_item;
+        return $item if $self->{pos} > $pos;
+    }
+}
+
+sub has_item_at_pos {
+    my ($self, $pos) = @_;
+    return 1 if $self->{pos} > $pos;
+    while (1) {
+        return 0 unless $self->has_next_item;
+        $self->get_next_item;
+        return 1 if $self->{pos} > $pos;
+    }
+}
+
 1;
 # ABSTRACT: Role to access array data from DATA section, one line per element
 
@@ -63,12 +83,16 @@ ArrayDataRole::Source::LinesInDATA - Role to access array data from DATA section
 
 =head1 VERSION
 
-This document describes version 0.004 of ArrayDataRole::Source::LinesInDATA (from Perl distribution ArrayDataRoles-Standard), released on 2021-04-25.
+This document describes version 0.005 of ArrayDataRole::Source::LinesInDATA (from Perl distribution ArrayDataRoles-Standard), released on 2021-05-03.
 
 =head1 DESCRIPTION
 
 This role expects array data in lines in the DATA section.
 
+Note: C<get_item_at_pos()> and C<has_item_at_pos()> are slow (O(n) in worst
+case) because they iterate. Caching might be added in the future to speed this
+up.
+
 =for Pod::Coverage ^(.+)$
 
 =head1 ROLES MIXED IN
@@ -85,7 +109,7 @@ Source repository is at L<https://github.com/perlancar/perl-ArrayDataRoles-Stand
 
 =head1 BUGS
 
-Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=ArrayDataRoles-Standard>
+Please report any bugs or feature requests on the bugtracker website L<https://github.com/perlancar/perl-ArrayDataRoles-Standard/issues>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
